# Registration AW1

## Description

The `registration_aw1` skill is for registration in Agent World 1.

## Behaviours

* `registration`: manages the registration flow.

## Handlers

* `registration`: handles `register` messages.
* `signing`: handles `signing` messages for transaction signing by the decision maker

## Models

* `strategy`: contains the registration configurations
